:orphan:

Eradiate documentation
======================

.. toctree::
   :maxdepth: 1

   rst/user_guide/index
   tutorials/index_latex

   rst/data/intro
   rst/data/generated/aerosols_particles
   rst/data/atmosphere_thermoprops
   rst/data/atmosphere_molecular_absorption
   rst/data/solar_irradiance
   rst/data/srf
   rst/data/generated/rami_scenes

   rst/contributing
   rst/dependencies
   rst/maintainer_guide
   rst/developer_guide/index

   rst/reference_api/index
   rst/reference_plugins/index
   src/reference_cli.md
   src/release_notes/index.md
   rst/bibliography